@@ -1,4 +1,4 @@
-/* electric_field.h -- This file is part of Archimedes release 0.1.2
+/* electric_field.h -- This file is part of Archimedes release 1.0.0
    Archimedes is a simulator for Submicron 2D III-V semiconductor
    Devices. It implements the Monte Carlo method and a simplfied
    version of the MEP model (Maximum Entropy Principle model)
@@ -7,7 +7,9 @@
    of effective potential method. It is now able to simulate applied
    magnetic fields along with self consistent Faraday equation.
 
-   Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
+   Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Jean Michel Sellier
+   <jeanmichel.sellier@gmail.com>
+   <jsellier@purdue.edu>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,7 +28,7 @@
 
 // ######################################################
 // Created on 10 Mar.2004, Siracusa, J.M.Sellier
-// Last modif. : 13 Sep.2007, Siracusa, J.M.Sellier
+// Last modif. : 12 Aug.2011, Carry le Rouet, J.M.Sellier
 // ######################################################
 
 // Computation of the electrostatic potential,
@@ -37,7 +39,7 @@
 // the minimum energy of the semiconductor material
 // in order to take into account heterostructures.
 // For more information see the manual of 
-// GNU Archimedes release 0.1.0.
+// GNU Archimedes release 1.0.0.
 
 void 
 Electric_Field(void)
@@ -96,7 +98,7 @@ Electric_Field(void)
        PSI[k][j]=u2d[k][j][0];
    for(k=2;k<=ny;k++)
      for(j=2;j<=nx;j++){
-       kappa=(EPSR[i_dom[k][j]])/Q;
+       kappa=(EPSR[i_dom[k][j]]*EPS0)/Q;
        deltat=factor*0.5/kappa/(1./(dx*dx)+1./(dy*dy));
        rho=(u2d[j][k][1]-N_D[j][k]-h2d[j][k][1]+N_H[j][k]);
        u2d[j][k][0]=PSI[j][k]-deltat*rho+deltat*kappa*
@@ -150,7 +152,7 @@ Electric_Field(void)
 // take into account heterostructures
    for(j=0;j<=ny+1;j++)
      for(i=0;i<=nx+1;i++)
-       u2d[i][j][0]=PSI[i][j]-EMIN[i_dom[i][j]][1];
+       u2d[i][j][0]-=EMIN[i_dom[i][j]][1];
 
  if(Quantum_Flag==1){
    printf("Computation of Quantum Effects\n");
